==> 0.1.0.tar.gz: android/src/main/kotlin/com/mapmyindia/sdk/flutter/nearby/mapmyindia_nearby_plugin/Utils.kt <==
package com.mapmyindia.sdk.flutter.nearby.mapmyindia_nearby_plugin

import android.content.Context
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.graphics.Color
import com.mapbox.mapboxsdk.utils.BitmapUtils
import com.mapmyindia.sdk.nearby.plugin.CategoryCode
import com.mapmyindia.sdk.nearby.plugin.model.NearbyOption
import com.mapmyindia.sdk.nearby.plugin.model.NearbyUIOption

/**
 ** Created by Saksham on 14-04-2021.
 **/
object Utils {

    fun getNearbyOptions(map: Map<String, Any?>): NearbyOption {
        val builder = NearbyOption.builder()
        if(map.containsKey("radius")) {
            val radius = map["radius"] as Int?
            if (radius != null) {
                builder.radius(map["radius"] as Int)
            }
        }
        if(map.containsKey("bounds")) {
            builder.bounds(map["bounds"] as String?)
        }
        if(map.containsKey("explain")) {
            builder.explain(map["explain"] as Boolean?)
        }
        if(map.containsKey("filter")) {
            builder.filter(map["filter"] as String?)
        }
        if(map.containsKey("pod")) {
            builder.pod(map["pod"] as String?)
        }
        if(map.containsKey("richData")) {
            builder.richData(map["richData"] as Boolean?)
        }
        if(map.containsKey("searchBy")) {
            builder.searchBy(map["searchBy"] as String?)
        }
        if(map.containsKey("sortBy")) {
            builder.sortBy(map["sortBy"] as String?)
        }
        return builder.build()
    }

    fun getNearbyUIOption(map: Map<String, Any?>): NearbyUIOption {
        val builder: NearbyUIOption.Builder = NearbyUIOption.builder()
        if(map.containsKey("backgroundColor")) {
            builder.backgroundColor(Color.parseColor(map["backgroundColor"] as String))
        }
        if(map.containsKey("refLocationCircleColor")) {
            builder.refLocationCircleColor(Color.parseColor(map["refLocationCircleColor"] as String))
        }
        if(map.containsKey("circleAlpha")) {
            builder.refLocationCircleAlpha((map["circleAlpha"] as Double).toFloat())
        }
        if(map.containsKey("paginationContainerViewBackgroundColor")) {
            builder.paginationBackgroundColor(Color.parseColor(map["paginationContainerViewBackgroundColor"] as String))
        }
        if(map.containsKey("placeNameTextColor")) {
            builder.placeNameTextColor(Color.parseColor(map["placeNameTextColor"] as String))
        }
        if(map.containsKey("placeAddressTextColor")) {
            builder.placeAddressTextColor(Color.parseColor(map["placeAddressTextColor"] as String))
        }
        if(map.containsKey("distanceTextColor")) {
            builder.distanceTextColor(Color.parseColor(map["distanceTextColor"] as String))
        }
        if(map.containsKey("navigationBackgroundColor")) {
            builder.toolbarColor(Color.parseColor(map["navigationBackgroundColor"] as String))
        }
        if(map.containsKey("segmentedControlSelectedSegmentTintColor")) {
            builder.tabIndicatorColor(Color.parseColor(map["segmentedControlSelectedSegmentTintColor"] as String))
            builder.selectedTabTextColor(Color.parseColor(map["segmentedControlSelectedSegmentTintColor"] as String))
        }
        if(map.containsKey("segmentedControlBackgroundColor")) {
            builder.tabBackgroundColor(Color.parseColor(map["segmentedControlBackgroundColor"] as String))
        }
        if(map.containsKey("segmentedControlUnselectedforegroundColor")) {
            builder.tabTextColor(Color.parseColor(map["segmentedControlUnselectedforegroundColor"] as String))
        }
        if(map.containsKey("tableCellBackgroundColor")) {
            builder.detailListBackgroundColor(Color.parseColor(map["tableCellBackgroundColor"] as String))
        }
        if(map.containsKey("tableCellSeparatorColor")) {
            builder.detailListSeperatorBackgroundColor(Color.parseColor(map["tableCellSeparatorColor"] as String))
        }
        if(map.containsKey("paginationPreviousButtonbackgroundcolor")) {
            builder.prevButtonBackgroundColor(Color.parseColor(map["paginationPreviousButtonbackgroundcolor"] as String))
        }
        if(map.containsKey("paginationNextButtonbackgroundcolor")) {
            builder.nextButtonBackgroundColor(Color.parseColor(map["paginationNextButtonbackgroundcolor"] as String))
        }
        if(map.containsKey("nearbyFilterViewContainerBackgroundColor")) {
            builder.categoryFilterBackgroundColor(Color.parseColor(map["nearbyFilterViewContainerBackgroundColor"] as String))
        }
        if(map.containsKey("refLocationIcon")) {
            val icon: ByteArray = map["refLocationIcon"] as ByteArray
            builder.refLocationIcon(BitmapFactory.decodeByteArray(icon, 0, icon.size))
        }
        if(map.containsKey("navigationTitleColor")) {
            builder.toolbarTintColor(Color.parseColor(map["navigationTitleColor"] as String))
        }
        if(map.containsKey("nearbyToolbarColor")) {
            builder.nearbyToolbarColor(Color.parseColor(map["nearbyToolbarColor"] as String))
        }
        if(map.containsKey("nearbyToolbarTintColor")) {
            builder.nearbyToolbarTintColor(Color.parseColor(map["nearbyToolbarTintColor"] as String))
        }
        if(map.containsKey("categoryBackgroundColor")) {
            builder.categoryBackgroundColor(Color.parseColor(map["categoryBackgroundColor"] as String))
        }
        if(map.containsKey("categoryTextColor")) {
            builder.categoryTextColor(Color.parseColor(map["categoryTextColor"] as String))
        }
        if(map.containsKey("categoryIconColor")) {
            builder.categoryTintColor(Color.parseColor(map["categoryIconColor"] as String))
        }
        if(map.containsKey("changeLocationButtonTextColor")) {
            builder.changeLocationButtonTextColor(Color.parseColor(map["changeLocationButtonTextColor"] as String))
        }
        if(map.containsKey("locationDetailFormattedAddressTextColor")) {
            builder.locationDetailFormattedAddressTextColor(Color.parseColor(map["locationDetailFormattedAddressTextColor"] as String))
        }
        if(map.containsKey("locationDetailInfoTextColor")) {
            builder.locationDetailInfoTextColor(Color.parseColor(map["locationDetailInfoTextColor"] as String))
        }
        if(map.containsKey("locationDetailsBackgroundColor")) {
            builder.locationDetailsBackgroundColor(Color.parseColor(map["locationDetailsBackgroundColor"] as String))
        }
        if(map.containsKey("locationDetailsInfoLabelText")) {
            builder.locationDetailsInfoLabelText(map["locationDetailsInfoLabelText"] as String)
        }
        if(map.containsKey("nearbyToolbarIcon")) {
            val icon: ByteArray = map["nearbyToolbarIcon"] as ByteArray
            builder.nearbyToolbarIcon(BitmapFactory.decodeByteArray(icon, 0, icon.size))
        }
        if(map.containsKey("selectedCategoryBackgroundColor")) {
            builder.selectedCategoryBackgroundColor(Color.parseColor(map["selectedCategoryBackgroundColor"] as String))
        }
        if(map.containsKey("selectedCategoryTextColor")) {
            builder.selectedCategoryTextColor(Color.parseColor(map["selectedCategoryTextColor"] as String))
        }
        if(map.containsKey("selectedCategoryIconColor")) {
            builder.selectedCategoryTintColor(Color.parseColor(map["selectedCategoryIconColor"] as String))
        }
        if(map.containsKey("submitButtonColor")) {
            builder.submitButtonColor(Color.parseColor(map["submitButtonColor"] as String))
        }
        if(map.containsKey("submitButtonText")) {
            builder.submitButtonText(map["submitButtonText"] as String)
        }
        if(map.containsKey("useCurrentLocationButtonTextColor")) {
            builder.useCurrentLocationButtonTextColor(Color.parseColor(map["useCurrentLocationButtonTextColor"] as String))
        }
        if(map.containsKey("submitButtonTextColor")) {
            builder.submitButtonTextColor(Color.parseColor(map["submitButtonTextColor"] as String))
        }
        return builder.build();
    }

    fun getCategoryCode( map: Map<String, Any?>): CategoryCode {
        val category: String = map["category"] as String
        val icon: ByteArray = map["icon"] as ByteArray
        val markerIcon: ByteArray = map["markerIcon"] as ByteArray
        val categoryCode: List<String> = map["categoryCode"] as List<String>
        val iconBitmap: Bitmap = BitmapFactory.decodeByteArray(icon, 0, icon.size)
        val markerIconBitmap: Bitmap = BitmapFactory.decodeByteArray(markerIcon, 0, markerIcon.size)
        if (map.containsKey("isSelected")) {
            return CategoryCode(category, iconBitmap, categoryCode, markerIconBitmap, map["isSelecte"] as Boolean)
        } else {
            return CategoryCode(category, iconBitmap, categoryCode, markerIconBitmap)
        }
    }
}

==> 0.2.0.tar.gz: android/src/main/kotlin/com/mapmyindia/sdk/flutter/nearby/mapmyindia_nearby_plugin/Utils.kt <==
package com.mapmyindia.sdk.flutter.nearby.mapmyindia_nearby_plugin

import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.graphics.Color
import com.mapmyindia.sdk.nearby.plugin.CategoryCode
import com.mapmyindia.sdk.nearby.plugin.model.NearbyOption
import com.mapmyindia.sdk.nearby.plugin.model.NearbyUIOption

/**
 ** Created by Saksham on 14-04-2021.
 **/
object Utils {

    fun getNearbyOptions(map: Map<String, Any?>): NearbyOption {
        val builder = NearbyOption.builder()
        if(map.containsKey("radius")) {
            val radius = map["radius"] as Int?
            if (radius != null) {
                builder.radius(map["radius"] as Int)
            }
        }
        if(map.containsKey("bounds")) {
            builder.bounds(map["bounds"] as String?)
        }
        if(map.containsKey("explain")) {
            builder.explain(map["explain"] as Boolean?)
        }
        if(map.containsKey("filter")) {
            builder.filter(map["filter"] as String?)
        }
        if(map.containsKey("pod")) {
            builder.pod(map["pod"] as String?)
        }
        if(map.containsKey("richData")) {
            builder.richData(map["richData"] as Boolean?)
        }
        if(map.containsKey("searchBy")) {
            builder.searchBy(map["searchBy"] as String?)
        }
        if(map.containsKey("sortBy")) {
            builder.sortBy(map["sortBy"] as String?)
        }
        if(map.containsKey("userName")) {
            builder.userName(map["userName"] as String?)
        }
        return builder.build()
    }

    fun getNearbyUIOption(map: Map<String, Any?>): NearbyUIOption {
        val builder: NearbyUIOption.Builder = NearbyUIOption.builder()
        if(map.containsKey("backgroundColor")) {
            builder.backgroundColor(Color.parseColor(map["backgroundColor"] as String))
        }
        if(map.containsKey("refLocationCircleColor")) {
            builder.refLocationCircleColor(Color.parseColor(map["refLocationCircleColor"] as String))
        }
        if(map.containsKey("circleAlpha")) {
            builder.refLocationCircleAlpha((map["circleAlpha"] as Double).toFloat())
        }
        if(map.containsKey("paginationContainerViewBackgroundColor")) {
            builder.paginationBackgroundColor(Color.parseColor(map["paginationContainerViewBackgroundColor"] as String))
        }
        if(map.containsKey("placeNameTextColor")) {
            builder.placeNameTextColor(Color.parseColor(map["placeNameTextColor"] as String))
        }
        if(map.containsKey("placeAddressTextColor")) {
            builder.placeAddressTextColor(Color.parseColor(map["placeAddressTextColor"] as String))
        }
        if(map.containsKey("distanceTextColor")) {
            builder.distanceTextColor(Color.parseColor(map["distanceTextColor"] as String))
        }
        if(map.containsKey("navigationBackgroundColor")) {
            builder.toolbarColor(Color.parseColor(map["navigationBackgroundColor"] as String))
        }
        if(map.containsKey("segmentedControlSelectedSegmentTintColor")) {
            builder.tabIndicatorColor(Color.parseColor(map["segmentedControlSelectedSegmentTintColor"] as String))
            builder.selectedTabTextColor(Color.parseColor(map["segmentedControlSelectedSegmentTintColor"] as String))
        }
        if(map.containsKey("segmentedControlBackgroundColor")) {
            builder.tabBackgroundColor(Color.parseColor(map["segmentedControlBackgroundColor"] as String))
        }
        if(map.containsKey("segmentedControlUnselectedforegroundColor")) {
            builder.tabTextColor(Color.parseColor(map["segmentedControlUnselectedforegroundColor"] as String))
        }
        if(map.containsKey("tableCellBackgroundColor")) {
            builder.detailListBackgroundColor(Color.parseColor(map["tableCellBackgroundColor"] as String))
        }
        if(map.containsKey("tableCellSeparatorColor")) {
            builder.detailListSeperatorBackgroundColor(Color.parseColor(map["tableCellSeparatorColor"] as String))
        }
        if(map.containsKey("paginationPreviousButtonbackgroundcolor")) {
            builder.prevButtonBackgroundColor(Color.parseColor(map["paginationPreviousButtonbackgroundcolor"] as String))
        }
        if(map.containsKey("paginationNextButtonbackgroundcolor")) {
            builder.nextButtonBackgroundColor(Color.parseColor(map["paginationNextButtonbackgroundcolor"] as String))
        }
        if(map.containsKey("nearbyFilterViewContainerBackgroundColor")) {
            builder.categoryFilterBackgroundColor(Color.parseColor(map["nearbyFilterViewContainerBackgroundColor"] as String))
        }
        if(map.containsKey("refLocationIcon")) {
            val icon: ByteArray = map["refLocationIcon"] as ByteArray
            builder.refLocationIcon(BitmapFactory.decodeByteArray(icon, 0, icon.size))
        }
        if(map.containsKey("navigationTitleColor")) {
            builder.toolbarTintColor(Color.parseColor(map["navigationTitleColor"] as String))
        }
        if(map.containsKey("nearbyToolbarColor")) {
            builder.nearbyToolbarColor(Color.parseColor(map["nearbyToolbarColor"] as String))
        }
        if(map.containsKey("nearbyToolbarTintColor")) {
            builder.nearbyToolbarTintColor(Color.parseColor(map["nearbyToolbarTintColor"] as String))
        }
        if(map.containsKey("categoryBackgroundColor")) {
            builder.categoryBackgroundColor(Color.parseColor(map["categoryBackgroundColor"] as String))
        }
        if(map.containsKey("categoryTextColor")) {
            builder.categoryTextColor(Color.parseColor(map["categoryTextColor"] as String))
        }
        if(map.containsKey("categoryIconColor")) {
            builder.categoryTintColor(Color.parseColor(map["categoryIconColor"] as String))
        }
        if(map.containsKey("changeLocationButtonTextColor")) {
            builder.changeLocationButtonTextColor(Color.parseColor(map["changeLocationButtonTextColor"] as String))
        }
        if(map.containsKey("locationDetailFormattedAddressTextColor")) {
            builder.locationDetailFormattedAddressTextColor(Color.parseColor(map["locationDetailFormattedAddressTextColor"] as String))
        }
        if(map.containsKey("locationDetailInfoTextColor")) {
            builder.locationDetailInfoTextColor(Color.parseColor(map["locationDetailInfoTextColor"] as String))
        }
        if(map.containsKey("locationDetailsBackgroundColor")) {
            builder.locationDetailsBackgroundColor(Color.parseColor(map["locationDetailsBackgroundColor"] as String))
        }
        if(map.containsKey("locationDetailsInfoLabelText")) {
            builder.locationDetailsInfoLabelText(map["locationDetailsInfoLabelText"] as String)
        }
        if(map.containsKey("nearbyToolbarIcon")) {
            val icon: ByteArray = map["nearbyToolbarIcon"] as ByteArray
            builder.nearbyToolbarIcon(BitmapFactory.decodeByteArray(icon, 0, icon.size))
        }
        if(map.containsKey("selectedCategoryBackgroundColor")) {
            builder.selectedCategoryBackgroundColor(Color.parseColor(map["selectedCategoryBackgroundColor"] as String))
        }
        if(map.containsKey("selectedCategoryTextColor")) {
            builder.selectedCategoryTextColor(Color.parseColor(map["selectedCategoryTextColor"] as String))
        }
        if(map.containsKey("selectedCategoryIconColor")) {
            builder.selectedCategoryTintColor(Color.parseColor(map["selectedCategoryIconColor"] as String))
        }
        if(map.containsKey("submitButtonColor")) {
            builder.submitButtonColor(Color.parseColor(map["submitButtonColor"] as String))
        }
        if(map.containsKey("submitButtonText")) {
            builder.submitButtonText(map["submitButtonText"] as String)
        }
        if(map.containsKey("useCurrentLocationButtonTextColor")) {
            builder.useCurrentLocationButtonTextColor(Color.parseColor(map["useCurrentLocationButtonTextColor"] as String))
        }
        if(map.containsKey("submitButtonTextColor")) {
            builder.submitButtonTextColor(Color.parseColor(map["submitButtonTextColor"] as String))
        }
        return builder.build();
    }

    fun getCategoryCode( map: Map<String, Any?>): CategoryCode {
        val category: String = map["category"] as String
        val icon: ByteArray = map["icon"] as ByteArray
        val markerIcon: ByteArray = map["markerIcon"] as ByteArray
        val categoryCode: List<String> = map["categoryCode"] as List<String>
        val iconBitmap: Bitmap = BitmapFactory.decodeByteArray(icon, 0, icon.size)
        val markerIconBitmap: Bitmap = BitmapFactory.decodeByteArray(markerIcon, 0, markerIcon.size)
        return if (map.containsKey("isSelected")) {
            CategoryCode(category, iconBitmap, categoryCode, markerIconBitmap, map["isSelected"] as Boolean)
        } else {
            CategoryCode(category, iconBitmap, categoryCode, markerIconBitmap)
        }
    }
}
